@@ -1,4 +1,4 @@
-/* $Id: gucharmap-window.c,v 1.74 2006/02/21 00:07:16 behdad Exp $ */
+/* $Id: gucharmap-window.c,v 1.77 2006/07/24 23:23:05 behdad Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -358,11 +358,6 @@ help_about (GtkAction       *action,
 			       _(license[2]), "\n\n", _(license[3]), "\n\n",
 			       _(license[4]), "\n\n", NULL);
 
-  const gchar *translator_credits;
-  translator_credits = _("translator-credits");
-  if (strcmp (translator_credits, "translator-credits") == 0)
-    translator_credits = NULL;
-
   gtk_show_about_dialog (GTK_WINDOW (guw),
   			 "authors", authors,
 			 "comments", _("GNOME Character Map\n"
@@ -373,7 +368,7 @@ help_about (GtkAction       *action,
 			 "license", license_trans,
 			 "name", _("Gucharmap"),
 			 "logo-icon-name", "gucharmap",
-			 "translator-credits", translator_credits,
+			 "translator-credits", _("translator-credits"),
 			 "version", VERSION,
 			 "website", "http://live.gnome.org/Gucharmap",
 			 "wrap-license", TRUE,
@@ -596,7 +591,7 @@ make_menu (GucharmapWindow *guw)
   g_object_unref (priv->accel_group);
 
   toggle_menu = gtk_toggle_action_new ( "SnapColumns",
-					"Snap Columns to Power of Two",
+					_("Snap Columns to Power of Two"),
 					NULL,
 					NULL);
   g_signal_connect (G_OBJECT(toggle_menu), "toggled", G_CALLBACK (snap_cols_pow2), guw);
@@ -882,7 +877,7 @@ gucharmap_window_class_init (GucharmapWindowClass *clazz)
   G_OBJECT_CLASS (clazz)->finalize = window_finalize;
   g_type_class_add_private (clazz, sizeof (GucharmapWindowPrivate));
 
-  gucharmap_intl_ensure_initialized ();
+  _gucharmap_intl_ensure_initialized ();
 }
 
 GType 
